@@ -204,7 +204,7 @@ by Perl would be interpreted as if the arguments were C<307080 000001
 
 =head1 AUTHOR
 
-Pl Sannes E<lt>pal.sannes@met.noE<gt>
+Pål Sannes E<lt>pal.sannes@met.noE<gt>
 
 =head1 COPYRIGHT
 
